@@ -38,6 +38,8 @@
 #include <kstdaction.h>
 #include <kpopupmenu.h>
 #include <kprocess.h>
+#include <kguiitem.h>
+#include <kstatusbar.h>
 
 #include <iostream.h>
 
@@ -57,7 +59,7 @@
 #include "utils.h"
 #include "rename.h"
 #include "createdb.h"
-
+#include "../config.h"
 #include <stdlib.h>
 
 #define ID_STATUS_MSG 1
@@ -216,12 +218,14 @@ void Mp3KultApp::insertInfoDB()
 	bool conn = false;
 	while (!conn)
 	{
+		KGuiItem butCreate(i18n("Create")), butConfig(i18n("Config"));
+
 		int res = KMessageBox::warningYesNoCancel (this, i18n("Error connecting to DataBase\n"
                                         "If it's your first start of Mp3Kult,\n"
 																				"click on Create to create the DataBase !\n"
 																				"Otherwise click on Config to change \n"
 																				"the configuration of DataBase"),
-								i18n("Error!") , "Create", "Config");
+								i18n("Error!") , butCreate, butConfig);
       /*int res = KMessageBox::questionYesNo(this, i18n("Error connecting to\n"
                                                       "DataBase\n"
                                                       "Do you want to change\n"
@@ -304,11 +308,11 @@ void Mp3KultApp::checkVersion()
 	config->setGroup("OPTIONS");
 	version = config->readEntry("Version");
 
-	if (version != "0.6")
+	if (version != VERSION)
 	{
-		config->writeEntry ("Version", "0.6");
+		config->writeEntry ("Version", VERSION);
 	}
-	cerr << "Version: 0.6" << endl;
+	cerr << "Version: "<< VERSION << endl;
 }
 
 
