@@ -500,7 +500,7 @@ void PLView::slotLocalPL()
           //MYSQL_RES* res;
           MYSQL_ROW row;
           //MyDb db;
-          int n=0;
+          //int n=0;
           int mp3num;
           QString cmd, newfile, locName, locPath;
 
@@ -544,8 +544,8 @@ void PLView::slotLocalPL()
 
                db->addEntryPL (row[ID_DB_PL_SONG], atoi(row[ID_DB_PL_LENGTH]),
                               "Local", locName, newfile,
-                              atoi(row[ID_DB_PL_MP3ID]), n);
-               n++;
+                              atoi(row[ID_DB_PL_MP3ID]), atoi(row[ID_DB_PL_ORDER]));
+               //n++;
                mp3kult->advProgBar(1);
                kapp->processEvents();
                cerr << "Local File: " << newfile << endl;
